@@ -15,7 +15,7 @@ class ParseHub:
     def _select_parser(self, url: str) -> Type[Parser] | None:
         """选择解析器"""
         for parser in self.__parsers:
-            if parser().match(match_url(url)):
+            if parser().match(url):
                 return parser
 
     @staticmethod
@@ -30,6 +30,7 @@ class ParseHub:
         :param url: 分享链接
         """
         if parser := self._select_parser(url):
+            url = await parser().get_raw_url(url)
             return await parser(parse_config=self.config).parse(url)
         raise ValueError("不支持的平台")
 
