@@ -5,7 +5,8 @@ from urllib.parse import urlparse, parse_qs
 import httpx
 
 from ...config.config import ParseConfig
-from ...types import ParseResult
+from ...types import ParseResult, ParseError
+from ...utiles.utile import match_url
 
 
 class Parser(ABC):
@@ -27,6 +28,7 @@ class Parser(ABC):
 
     def match(self, url: str) -> bool:
         """判断是否匹配该解析器"""
+        url = match_url(url)
         return bool(re.match(self.__match__, url))
 
     @abstractmethod
@@ -40,13 +42,18 @@ class Parser(ABC):
         :param url: 链接
         :return:
         """
-
+        url = match_url(url)
         if any(map(lambda x: x in url, self.__redirect_keywords__)):
             async with httpx.AsyncClient(proxy=self.cfg.proxy) as client:
-                r = await client.get(
-                    url, follow_redirects=True, headers={"User-Agent": self.cfg.ua}
-                )
-                r.raise_for_status()
+                try:
+                    r = await client.get(
+                        url, follow_redirects=True, headers={"User-Agent": self.cfg.ua}
+                    )
+                    r.raise_for_status()
+                except httpx.ReadTimeout:
+                    raise ParseError("获取原始链接超时")
+                except Exception:
+                    raise ParseError("获取原始链接失败")
                 url = str(r.url)
 
         parsed_url = urlparse(url)
