@@ -15,11 +15,23 @@ from ...types import (
     ImageParseResult,
     Video,
     Subtitles,
-    DownloadResult, ParseError,
+    DownloadResult,
+    ParseError,
 )
+
 EXC = ProcessPoolExecutor()
 
 
+def download_video(yto_params: dict, urls: list[str]) -> None:
+    """在独立进程中下载视频"""
+    try:
+        with YoutubeDL(yto_params) as ydl:
+            return ydl.download(urls)
+    except Exception as e:
+        error_msg = f"{type(e).__name__}: {str(e)}"
+        raise ParseError(error_msg)
+
+
 class YtParser(Parser):
     """yt-dlp解析器"""
 
@@ -40,14 +52,18 @@ class YtParser(Parser):
             return YtVideoParseResult(video=video_info.url, **_d)
 
     async def _parse(self, url, params=None) -> "YtVideoInfo":
-        loop = asyncio.get_running_loop()
         try:
+            # dl = await asyncio.wait_for(
+            #     loop.run_in_executor(EXC, extract_video_info, url, params), timeout=30
+            # )
             dl = await asyncio.wait_for(
-                loop.run_in_executor(EXC, self._extract_info, url, params),
-                timeout=30
+                asyncio.to_thread(self._extract_info, url, params), timeout=30
             )
         except asyncio.TimeoutError:
             raise ParseError("解析视频信息超时")
+        except Exception as e:
+            raise ParseError(f"解析视频信息失败: {str(e)}")
+
         if dl.get("_type"):
             dl = dl["entries"][0]
             url = dl["webpage_url"]
@@ -64,9 +80,11 @@ class YtParser(Parser):
             duration=duration,
             url=url,
         )
+
     def _extract_info(self, url, params=None):
         with YoutubeDL(params or self.params) as ydl:
             return ydl.extract_info(url, download=False)
+
     # def hook(self, d):
     #     current = d.get("downloaded_bytes", 0)
     #     total = d.get("total_bytes", 0)
@@ -149,35 +167,32 @@ class YtVideoParseResult(VideoParseResult):
         loop = asyncio.get_running_loop()
         try:
             await asyncio.wait_for(
-                loop.run_in_executor(EXC, self._download, yto, [self.media.path]),
-                timeout=300
+                loop.run_in_executor(EXC, download_video, yto, [self.media.path]),
+                timeout=300,
             )
         except asyncio.TimeoutError:
             raise ParseError("下载超时")
 
-        video_path = (
-            v := list(dir_.glob("*.mp4"))
+        v = (
+            list(dir_.glob("*.mp4"))
             or list(dir_.glob("*.mkv"))
             or list(dir_.glob("*.webm"))
-        ) and v[0]
+        )
+        if not v:
+            raise ParseError("未获取到下载完成的视频")
+        video_path = v[0]
         subtitles = (v := list(dir_.glob("*.ttml"))) and Subtitles().parse(v[0])
         try:
-            thumb = await ImgHost().litterbox(self.dl.thumbnail)
-        except:
+            thumb = await ImgHost(proxies=config.proxy).litterbox(self.dl.thumbnail)
+        except Exception:
             thumb = None
-        # thumb = (
-        #     v := list(dir_.glob("*.webp")) or list(dir_.glob("*.jpg"))
-        # ) and await ImgHost().catbox(v[0])
+
         return DownloadResult(
             self,
             Video(path=str(video_path), subtitles=subtitles, thumb_url=thumb),
             dir_,
         )
 
-    @staticmethod
-    def _download(yto, urls: list[str]):
-        with YoutubeDL(yto) as ydl:
-            return ydl.download(urls)
 
 class YtImageParseResult(ImageParseResult):
     def __init__(
