@@ -16,12 +16,12 @@ class CoolapkParser(Parser):
     __platform__ = "酷安"
     __supported_type__ = ["图文"]
     __match__ = r"^(http(s)?://)www.(coolapk|coolapk1s).com/(feed|picture)/.*"
-    __reserved_parameters__ = ["shareKey"]
+    __reserved_parameters__ = ["shareKey", "s"]
     __redirect_keywords__ = ["coolapk1s"]
 
     async def parse(self, url: str) -> "CoolapkImageParseResult":
         url = await self.get_raw_url(url)
-        coolapk = await Coolapk.parse(url)
+        coolapk = await Coolapk.parse(url, proxy=self.cfg.proxy)
         return CoolapkImageParseResult(
             title=coolapk.title,
             photo=coolapk.imgs,
@@ -44,7 +44,7 @@ class CoolapkImageParseResult(ImageParseResult):
         callback: Callable = None,
         callback_args: tuple = (),
         config: DownloadConfig = DownloadConfig(),
-    ) -> "DownloadResult":
+    ) -> DownloadResult:
         headers = config.headers or {}
         headers["Accept"] = (
             "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.7"
@@ -61,8 +61,10 @@ class Coolapk:
     imgs: list[str] = None
 
     @classmethod
-    async def parse(cls, url: str) -> "Coolapk":
-        async with httpx.AsyncClient(headers={"User-Agent": GlobalConfig.ua}) as client:
+    async def parse(cls, url: str, proxy: str = None) -> "Coolapk":
+        async with httpx.AsyncClient(
+            headers={"User-Agent": GlobalConfig.ua}, proxy=proxy
+        ) as client:
             result = await client.get(url)
         soup = BeautifulSoup(result.text, "html.parser")
 
