@@ -6,7 +6,7 @@ from bs4 import BeautifulSoup
 from httpx import Response
 
 from ..base.base import Parser
-from ...types import VideoParseResult, ImageParseResult
+from ...types import VideoParseResult, ImageParseResult, ParseError
 
 
 class TieBaParser(Parser):
@@ -15,7 +15,11 @@ class TieBaParser(Parser):
     __match__ = r"^(http(s)?://)?.+tieba.baidu.com/p/\d+"
 
     async def parse(self, url: str) -> Union["ImageParseResult", "VideoParseResult"]:
-        tb = await TieBa(self.cfg.proxy).parse(url)
+        try:
+            tb = await TieBa(self.cfg.proxy).parse(url)
+        except Exception as e:
+            raise ParseError("贴吧解析失败") from e
+
         if tb.video_url:
             return VideoParseResult(
                 title=tb.title, video=tb.video_url, raw_url=url, desc=tb.content
@@ -70,20 +74,19 @@ class TieBa:
     async def get_the_content(self, html: Response):
         """获取帖子的标题和内容"""
         soup = BeautifulSoup(html.text, "html.parser")
-        title = (
-            soup.find("h3", {"class": ["core_title_txt", "pull-left", "text-overflow"]})
-            or soup.find("h1", {"class": "core_title_txt"})
-        ).text.strip()
+        title = soup.find(
+            "h3", {"class": ["core_title_txt", "pull-left", "text-overflow"]}
+        ) or soup.find("h1", {"class": "core_title_txt"})
+        if not title:
+            raise Exception("未获取到标题内容")
+        title = title.text.strip()
         content = soup.find("div", {"class": ["d_post_content", "j_d_post_content"]})
         content = self._parse_out_the_body(content)
         return title, content
 
     async def get_html(self, t_url) -> Response:
         async with httpx.AsyncClient(proxy=self.proxy) as c:
-            proxy = (await c.get("http://demo.spiderpy.cn/get/")).json().get("proxy")
-            res = await c.get(t_url, headers={"User-Agent": "Mozilla5.0/"})
-            await c.get(f"http://demo.spiderpy.cn/delete/?proxy={proxy}")
-            return res
+            return await c.get(t_url, headers={"User-Agent": "Mozilla5.0/"}, timeout=15)
 
     async def parse(self, t_url) -> "TieBaPost":
         res = await self.get_html(t_url)
