@@ -4,3 +4,7 @@ from dataclasses import dataclass
 @dataclass
 class SummaryResult:
     content: str
+
+
+class SummaryError(Exception):
+    pass
